Slot: annotations - LinkML Model

# Slot: annotations

a collection of tag/text tuples with the semantics of OWL Annotation

URI: linkml:annotations

## Domain and Range

Annotatable → 0..* Annotation

## Parents

- is_a: extensions

## Children

## Used by

- Annotatable
- Annotation
- ClassDefinition
- Definition
- Element
- EnumDefinition
- PermissibleValue
- SchemaDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition
- UniqueKey